# Table of Contents

- [meta-model](<./meta-model.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Meta Model](<./Meta-Model.md>)
  - [Overview of the SAP LeanIX Meta Model](<./Meta-Model/Overview-of-the-SAP-LeanIX-Meta-Model.md>)
  - [Layers of the SAP LeanIX Meta Model](<./Meta-Model/Layers-of-the-SAP-LeanIX-Meta-Model.md>)
  - [Fact Sheet Types](<./Meta-Model/Fact-Sheet-Types.md>)
  - [Fact Sheet Subtypes](<./Meta-Model/Fact-Sheet-Subtypes.md>)
  - [Is the SAP LeanIX Meta Model Configurable?](<./Meta-Model/Is-the-SAP-LeanIX-Meta-Model-Configurable.md>)
  - [Are Fact Sheet Subtypes Configurable?](<./Meta-Model/Are-Fact-Sheet-Subtypes-Configurable.md>)
  - [Is Moving from the Meta Model v3 to the Meta Model v4 Necessary?](<./Meta-Model/Is-Moving-from-the-Meta-Model-v3-to-the-Meta-Model-v4-Necessary.md>)
  - [Was this page helpful?](<./Meta-Model/Was-this-page-helpful.md>)
